@@ -19,8 +19,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Code:
 
@@ -267,7 +267,7 @@
     (setq parameters (riece-split-parameters
 		      (riece-decoded-string-for-identity decoded
 							 channel-identity))
-	  topic (nth 1 parameters))
+	  topic (nth 2 parameters))
     (riece-channel-set-topic (riece-get-channel channel) topic)
     (riece-insert-info buffer (concat visible " users, topic: " topic "\n"))
     (riece-insert-info
@@ -338,8 +338,8 @@
 
 (defun riece-handle-341-message (prefix number name string)
   (if (string-match "^\\([^ ]+\\) " string)
-      (let* ((channel (match-string 1 string))
-	     (user (substring string (match-end 0)))
+      (let* ((channel (substring string (match-end 0)))
+	     (user (match-string 1 string))
 	     (channel-identity (riece-make-identity channel riece-server-name))
 	     (buffer (riece-channel-buffer channel-identity)))
 	(riece-insert-info buffer (concat "Inviting " user "\n"))
