@@ -19,8 +19,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Code:
 
@@ -41,9 +41,9 @@
 	     (format "riece-handle-default-%03d-message" base-number))))
     (if (and function
 	     (symbol-function function))
-	(riece-ignore-errors (symbol-name function)
-	  (funcall function prefix number name
-		   (riece-decode-coding-string string))))))
+	(riece-funcall-ignore-errors (symbol-name function)
+				     function prefix number name
+				     (riece-decode-coding-string string)))))
 
 (defun riece-handle-message (prefix message string)
   (if (and prefix
@@ -56,13 +56,15 @@
   (let ((function (intern-soft (concat "riece-handle-" message "-message")))
 	(hook (intern (concat "riece-" message "-hook")))
 	(after-hook (intern (concat "riece-after-" message "-hook"))))
-    (unless (riece-ignore-errors (symbol-name hook)
-	      (run-hook-with-args-until-success hook prefix string))
+    (unless (riece-funcall-ignore-errors (symbol-name hook)
+					 #'run-hook-with-args-until-success
+					 hook prefix string)
       (if function
-	  (riece-ignore-errors (symbol-name function)
-	    (funcall function prefix string)))
-      (riece-ignore-errors (symbol-name after-hook)
-	(run-hook-with-args-until-success after-hook prefix string)))))
+	  (riece-funcall-ignore-errors (symbol-name function)
+				       function prefix string))
+      (riece-funcall-ignore-errors (symbol-name after-hook)
+				   #'run-hook-with-args-until-success
+				   after-hook prefix string))))
 
 (defsubst riece-chomp-string (string)
   (if (string-match "\r\\'" string)
@@ -76,8 +78,7 @@
     (insert input)
     (goto-char riece-read-point)
     (beginning-of-line)
-    (while (and (not (eobp))
-		(looking-at ".*\n"))	;the input line is not finished
+    (while (looking-at ".*\n")	;the input line is finished
       (save-excursion
 	(if (looking-at
 	     ":\\([^ ]+\\) +\\([0-5][0-9][0-9]\\) +\\([^ ]+\\) +\\(.*\\)")
@@ -118,10 +119,11 @@
 			 riece-server-name)))
       (if riece-debug
 	  (if (equal server-name "")
-	      (message "Connection closed: %s"
-		       (substring status 0 (1- (length status))))
-	    (message "Connection to \"%s\" closed: %s"
-		     server-name (substring status 0 (1- (length status)))))
+	      (riece-debug (format "Connection closed: %s"
+				   (substring status 0 (1- (length status)))))
+	    (riece-debug (format "Connection to \"%s\" closed: %s"
+				 server-name
+				 (substring status 0 (1- (length status))))))
 	(if (equal server-name "")
 	    (message "Connection closed")
 	  (message "Connection to \"%s\" closed" server-name)))
