@@ -19,8 +19,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Code:
 
@@ -66,10 +66,10 @@
   "If non-nil, attempt to reconnect with password.")
 
 (defvar riece-user-obarray-size 1327
-  "The size of obarray used by riece on username space.")
+  "The size of obarray used by riece on user name space.")
 
 (defvar riece-channel-obarray-size 103
-  "The size of obarray used by riece on channelname space.")
+  "The size of obarray used by riece on channel name space.")
 
 (defvar riece-addon-dependencies nil)
 
@@ -131,6 +131,12 @@ Local to the server buffers.")
 (defvar riece-coding-system nil
   "Coding system for process I/O.
 Local to the server buffers.")
+(defvar riece-channel-cache nil
+  "Cache of channel names.
+Local to the server buffers.")
+(defvar riece-user-cache nil
+  "Cache of user names.
+Local to the server buffers.")
 
 ;;; Variables local to the channel buffers:
 (defvar riece-freeze nil
