@@ -19,8 +19,8 @@
 
 ;; You should have received a copy of the GNU General Public License
 ;; along with GNU Emacs; see the file COPYING.  If not, write to the
-;; Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-;; Boston, MA 02111-1307, USA.
+;; Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+;; Boston, MA 02110-1301, USA.
 
 ;;; Code:
 
@@ -211,6 +211,11 @@ way is to put Riece variables on .emacs or file loaded from there."
   :group 'riece-server)
 
 (defcustom riece-username nil
+  "Your login name."
+  :type 'string
+  :group 'riece-server)
+
+(defcustom riece-realname nil
   "Your user name."
   :type 'string
   :group 'riece-server)
@@ -248,6 +253,16 @@ way is to put Riece variables on .emacs or file loaded from there."
   :type 'function
   :group 'riece-server)
 
+(defcustom riece-user-cache-max-size 512
+  "Maximum size of cache of user names."
+  :type 'integer
+  :group 'riece-server)
+
+(defcustom riece-channel-cache-max-size 512
+  "Maximum size of cache of channel names."
+  :type 'integer
+  :group 'riece-server)
+
 (defcustom riece-channel-buffer-mode t
   "When non-nil, Riece will display a channel buffer."
   :type 'boolean
